#!/usr/bin/env node
'use strict'

process.bin = process.title = 'vue'

var download = require('download-git-repo')
var program = require('commander')
var inquirer = require('inquirer')
var pkg = require('../package.json')
var fs = require('fs-extra')
var path = require('path')

// Parse version
program
  .version(pkg.version)

// Parse command
program
  .command("new <name>")
  .description("Generate a new vue project.")
  .action(function(name, options) {
    if (fs.existsSync(name)) {
      inquirer.prompt([{
        type: 'confirm',
        message: 'Target directory exists. Continue?',
        name: 'ok'
      }]).then(function (answers) {
        if (answers.ok) {
          templatePrompt(name)
        }
      })
    } else {
      templatePrompt(name)
    }
  })

// Select tempalte
function templatePrompt (name) {
  inquirer.prompt([{
    type: 'list',
    message: 'which template do you need:',
    name: 'template',
    choices: ['admin', 'desktop']
  }])
  .then(function (answers) {
    run(name, answers)
  })
}

// Get template and Create files
function run (name, answers) {
  console.log("Creating " + name + "...")
  var templatePath = ''
  if (answers.template === 'admin') {
    templatePath = path.join(__dirname, '../template/admin')
  } else if (answers.template === 'desktop') {
    templatePath = path.join(__dirname, '../template/desktop')
  } else {
    console.log('Command lost option "-a" or "-d"')
    return
  }
  var destinationPath = path.join(process.cwd(), name)
  fs.copy(templatePath, destinationPath, function (err) {
    if (err){
      return console.error(err)
    }
    console.log('Create Success!')
    console.log('cd')
  })
}

program.on('*', function(opt) {
  program.help();
})

program.parse(process.argv)

if (!process.argv.slice(2).length) {
  program.help()
}
