import axios from 'axios'
import { Message } from 'iview'

const baseUrl = process.env.baseUrl

const fetch = axios.create({
  baseURL: baseUrl, // api的base_url
  timeout: 10000    // 请求超时时间 10s
})

// request 请求发送之前 拦截器
fetch.interceptors.request.use(config => {
  const Authorization = localStorage.getItem('Authorization')
  if (Authorization) {
    config.headers.Authorization = Authorization
  }
  return config
}, error => {
  console.log(error) // for debug
  return Promise.reject(error)
})

// request 请求收到后 拦截器设置
fetch.interceptors.response.use(response => {
  if (response) {
    return response.data
  } else {
    Message.error(response.message)
  }
}, error => {
  return Promise.reject(error.response.data)   // 返回接口返回的错误信息
})

Object.freeze(fetch)

export default fetch
